Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/lps28_simpletest.py
    :caption: examples/lps28_simpletest.py
    :linenos:

Data rate settings
-------------------

Example showing the Data rate setting

.. literalinclude:: ../examples/lps28_data_rate.py
    :caption: examples/lps28_data_rate.py
    :linenos:

Resolution settings
--------------------

Example showing the Resolution setting

.. literalinclude:: ../examples/lps28_resolution.py
    :caption: examples/lps28_resolution.py
    :linenos:

Temperature Example
--------------------

Example showing how to verify the temperature

.. literalinclude:: ../examples/lps28_temperature.py
    :caption: examples/lps28_temperature.py
    :linenos:
